@@ -31,7 +31,9 @@ import gobject
 import sys, os, time
 from stat import *
 import time
-from datetime import date
+import datetime
+import calendar
+import email.utils as eut
 
 
 class account():
@@ -211,10 +213,9 @@ class account():
                  text = self.escapeText(x.text)
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, x.created_at, source, reply_to)
-                 #secsSinceEpoc = x.GetCreatedAtInSeconds()
-                 #msgDate = date.fromtimestamp(secsSinceEpoc)
-                 #print msgDate.ctime()
+                 created_at = self.parse_time(x.created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
+
                  self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -294,7 +295,8 @@ class account():
                  text = self.escapeText(x.text)
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, x.created_at, source, reply_to)
+                 created_at = self.parse_time(x.created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
                  self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -365,7 +367,8 @@ class account():
                  text = self.escapeText(x.text)
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.GetSenderId()), x.GetSenderScreenName(), "")
-                 formatted_tweet = self.format_tweet(user, text, x.created_at, None, None)
+                 created_at = self.parse_time(x.created_at)
+                 formatted_tweet = self.format_tweet(user, text, created_at, None, None)
                  self.dmstore.append([ "@" + user, x.GetSenderId(), "@" + user + " : " + text, "", x.id, "Tweet", x.created_at, "", "", pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -418,7 +421,8 @@ class account():
                     status = self.escapeText(status)
                     source = self.getSourceAppname(source)
                     pic = self.set_pic_for_id(str(x.id), x.GetScreenName(), x.GetProfileImageUrl())
-                    formatted_tweet = self.format_tweet(x.screen_name, status, tweettime, source, None)
+                    created_at = self.parse_time(tweettime)
+                    formatted_tweet = self.format_tweet(x.screen_name, status, created_at, source, None)
                     self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", x.id, "friend", tweettime, "", source, pic, formatted_tweet])
                     receive_count = receive_count + 1
 
@@ -497,7 +501,8 @@ class account():
                  text = self.escapeText(x.text)
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, x.created_at, source, reply_to)
+                 created_at = self.parse_time(x.created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
                  self.publicstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -552,7 +557,8 @@ class account():
                  text = self.escapeText(x.text)
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, x.created_at, source, reply_to)
+                 created_at = self.parse_time(x.created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
                  self.userhistorystore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -621,7 +627,8 @@ class account():
                     source = self.getSourceAppname(x['source'])
                     print "search result from userid: " + str(x['from_user_id'])
                     pic = self.get_pic_for_name(str(x['from_user']))
-                    formatted_tweet = self.format_tweet(x['from_user'], text, x['created_at'], source, reply_to)
+                    created_at = self.parse_time(x['created_at'])
+                    formatted_tweet = self.format_tweet(x['from_user'], text, created_at, source, reply_to)
                     self.searchstore.append([ "@" + x['from_user'], str(x['from_user_id']), "@" + x['from_user'] + " : " + text, "", x['id'], "Search", x['created_at'], reply_to, source, pic, formatted_tweet])
                     receive_count = receive_count + 1
                     note = osso.SystemNote(self.osso_c)
@@ -952,3 +959,44 @@ class account():
                 store.set_value(item, 9, pixbuf)
             item = store.iter_next(item)
 
+    def parse_time(self, timestr):
+        #parses a time string from twitter into a date object
+        try:
+            msgDate = datetime.datetime.strptime(timestr, "%a %b %d %H:%M:%S +0000 %Y")
+            #msgDate = date.fromtimestamp(secsSinceEpoc)
+
+            timestamp = msgDate.time()
+            print timestamp.tzinfo
+            #print datetime.datetime.tzname()
+            #msgDate = msgDate.astimezone(LocalTimezone())
+            t = time.time()
+
+            # we want something like '2007-10-18 14:00+0100'
+            if time.localtime(t).tm_isdst and time.daylight:
+                tz = time.altzone
+            else:
+                tz = time.timezone
+
+            td = datetime.timedelta(seconds=tz)
+            print td
+            timestamp = msgDate - td
+            mytz = "%+4.4d" % (tz / -(60 * 60) * 100) # time.timezone counts westwards!
+            print timestamp
+
+            dt = msgDate
+            nowstring = timestamp.strftime('%a, %b %d %Y %H:%M:%S')  # %Z (timezone) would be empty
+            #nowstring = "%s%s" % (dts, mytz)
+
+            print nowstring
+            return nowstring
+
+            return msgDate.ctime()
+        except ValueError:
+            msgDate = datetime.datetime.strptime(timestr, "%a %b %d %Y %H:%M:%S +0000")
+            #msgDate = date.fromtimestamp(secsSinceEpoc)
+
+            today = datetime.date.today()
+
+            #print datetime.datetime.tzname()
+            #msgDate = msgDate.astimezone(datetime.tzinfo("GMT +1"))
+            return msgDate.ctime()
